Module phys_rc

Module phys_rc 

A helper module for thread safety

Structs

Strong
A thread-safe reference-counting pointer to a reader-writer lock
Weak
A non-owning reference to the managed allocation

Type Aliases

PhysacHandleReadGuard
RAII structure used to release the shared read access of a lock when dropped, implemented as a std::sync::RwLockReadGuard<'a, T>
PhysacHandleWriteGuard
RAII structure used to release the shared write access of a lock when dropped, implemented as a std::sync::RwLockWriteGuard<'a, T>
PhysacReadGuard
RAII structure used to release the shared read access of a lock when dropped, implemented as a std::sync::RwLockReadGuard<'a, T>
PhysacWriteGuard
RAII structure used to release the shared read access of a lock when dropped, implemented as a std::sync::RwLockWriteGuard<'a, T>