PhysacWriteGuard

Type Alias PhysacWriteGuard 

pub type PhysacWriteGuard<'a, T> = RwLockWriteGuard<'a, T>;
RAII structure used to release the shared read access of a lock when dropped, implemented as a std::sync::RwLockWriteGuard<'a, T>

This structure is created by the Strong::borrow_mut method

Aliased Type

pub struct PhysacWriteGuard<'a, T> { /* private fields */ }