A helper module for thread safety
Structs
- Strong
- A thread-safe reference-counting pointer to a reader-writer lock
- Weak
- A non-owning reference to the managed allocation
Type Aliases
- Physac
Handle Read Guard - RAII structure used to release the shared read access of a lock when dropped, implemented as a
std::sync::RwLockReadGuard<'a, T> - Physac
Handle Write Guard - RAII structure used to release the shared write access of a lock when dropped, implemented as a
std::sync::RwLockWriteGuard<'a, T> - Physac
Read Guard - RAII structure used to release the shared read access of a lock when dropped, implemented as a
std::sync::RwLockReadGuard<'a, T> - Physac
Write Guard - RAII structure used to release the shared read access of a lock when dropped, implemented as a
std::sync::RwLockWriteGuard<'a, T>