pub type PhysacReadGuard<'a, T> = RwLockReadGuard<'a, T>;Expand description
RAII structure used to release the shared read access of a lock when dropped, implemented as a
std::sync::RwLockReadGuard<'a, T>
This structure is created by the Strong::borrow method
Aliased Type
pub struct PhysacReadGuard<'a, T> { /* private fields */ }